% created by Nils Hase 2016 (nilshase@math.uni-bremen.de)

% Fast Iterative Shrinkage Thresholding coupled with the Morozov parameter
% choice rule for problems of the type
%
% x^* = arg min_{x} 1/2*||Ax-y||_2^2 + alpha*||x||_1
% s.t. x >= 0

% Almost identical code to FISTA_L1, but with projection step,
% differs from FISTA_L2_pos by the shrinkage step

function [x_opt,alpha_opt] = FISTA_L1_pos(A,y,x_0,alpha,plotter)

delta = 1;

lambda = 1/norm(A,'fro')^2;
max_iter = 1000;
tol = 10^-6;
tau = 1;

discrepancy = zeros(size(alpha));

x_opt = x_0;
for k = 1:length(alpha)
    x = x_0;
    x_old = x_0;
    
    for kk = 1:max_iter
        x_old_old = x_old;
        x_old = x;
        
        % FISTA-update
        xx = x_old + (kk-2)/(kk+1)*(x_old - x_old_old);
        x = xx - lambda*(A'*(A*xx - y));
        
        % Shrinkage-step (L1)
        x = sign(x).*max(abs(x)-alpha(k)*lambda,0);

        % Projection step
        x(x<0) = 0;
        
        if norm(x_old - x) < tol
            break;
        end
    end

    discrepancy(k) = norm(A*x - y)/sqrt(length(y));
      
    x_opt = x;
    alpha_opt = alpha(k);
    % Morozov's discrepancy principle
    if discrepancy(k) < tau*delta
        fprintf('   Discrepancy principle found optimal alpha!\n')
        break;
    end
end

if plotter == 1
    figure();
    plot(log10(alpha),discrepancy)
    hold on;
    plot([log10(alpha(1)),log10(alpha(end))],tau*delta*[1,1],'r--')
    title('Diskrepanzkurve FISTA L1 pos')
    hold off;
end

end
